(********************************************************************)
(*                                                                  *)
(*  The Why3 Verification Platform   /   The Why3 Development Team  *)
(*  Copyright 2010-2013   --   INRIA - CNRS - Paris-Sud University  *)
(*                                                                  *)
(*  This software is distributed under the terms of the GNU Lesser  *)
(*  General Public License version 2.1, with the special exception  *)
(*  on linking described in file LICENSE.                           *)
(*                                                                  *)
(********************************************************************)

(*i camlp4deps: "parsing/grammar.cma" i*)

open Why3tac

let _ =
  begin try
    let _ =
      Tacinterp.add_tactic "Why3"
        (function
           [s] when Genarg.genarg_tag s = Genarg.StringArgType && true ->
             let s = Genarg.out_gen Genarg.wit_string s in why3tac s
         | [s; n]
           when
             Genarg.genarg_tag s = Genarg.StringArgType &&
             Genarg.genarg_tag n = Genarg.IntArgType && true ->
             let s = Genarg.out_gen Genarg.wit_string s in
             let n = Genarg.out_gen Genarg.wit_int n in why3tac ~timelimit:n s
         | _ -> failwith "Extension: cannot occur")
    in
    List.iter
      (fun (s, l) ->
         match l with
           Some l ->
             Tacinterp.add_primitive_tactic s
               (Tacexpr.TacAtom
                  (Util.dummy_loc,
                   Tacexpr.TacExtend (Util.dummy_loc, "Why3", l)))
         | None -> ())
      []
  with e when Errors.noncritical e ->
    Pp.msg_warning
      (Stream.iapp (Pp.str ("Exception in tactic extend " ^ "Why3" ^ ": "))
         (Errors.print e))
  end;
  Egrammar.extend_tactic_grammar "Why3"
    [[Egrammar.GramTerminal "why3";
      Egrammar.GramNonTerminal
        (Util.dummy_loc, Genarg.StringArgType, Pcoq.Aentry ("prim", "string"),
         Some (Names.id_of_string "s"))];
     [Egrammar.GramTerminal "why3";
      Egrammar.GramNonTerminal
        (Util.dummy_loc, Genarg.StringArgType, Pcoq.Aentry ("prim", "string"),
         Some (Names.id_of_string "s"));
      Egrammar.GramTerminal "timelimit";
      Egrammar.GramNonTerminal
        (Util.dummy_loc, Genarg.IntArgType, Pcoq.Aentry ("prim", "integer"),
         Some (Names.id_of_string "n"))]];
  List.iter Pptactic.declare_extra_tactic_pprule
    ["Why3", [Genarg.StringArgType], (0, [Some "why3"; None]);
     "Why3", [Genarg.StringArgType; Genarg.IntArgType],
     (0, [Some "why3"; None; Some "timelimit"; None])]
